==> v5.0.21.zip: ethers.js/docs/v5/api/README.md <==
-----

Documentation: [html](https://docs.ethers.io/)

-----

Application Programming Interface
=================================

* [Providers](providers)
  * [Provider](providers/provider)
    * [Accounts Methods](providers/provider)
    * [Blocks Methods](providers/provider)
    * [Ethereum Naming Service (ENS) Methods](providers/provider)
    * [Logs Methods](providers/provider)
    * [Network Status Methods](providers/provider)
    * [Transactions Methods](providers/provider)
    * [Event Emitter Methods](providers/provider)
    * [Inspection Methods](providers/provider)
  * [JsonRpcProvider](providers/jsonrpc-provider)
    * [JsonRpcSigner](providers/jsonrpc-provider)
    * [JsonRpcUncheckedSigner](providers/jsonrpc-provider)
    * [Node-Specific Methods](providers/jsonrpc-provider)
  * [API Providers](providers/api-providers)
    * [EtherscanProvider](providers/api-providers)
    * [InfuraProvider](providers/api-providers)
    * [AlchemyProvider](providers/api-providers)
    * [CloudflareProvider](providers/api-providers)
  * [Other Providers](providers/other)
    * [FallbackProvider](providers/other)
    * [IpcProvider](providers/other)
    * [UrlJsonRpcProvider](providers/other)
    * [Web3Provider](providers/other)
    * [WebSocketProvider](providers/other)
  * [Types](providers/types)
    * [BlockTag](providers/types)
    * [Networkish](providers/types)
    * [Network](providers/types)
    * [Block](providers/types)
    * [Events and Logs](providers/types)
    * [Transactions](providers/types)
* [Signers](signer)
  * [Signer](signer)
  * [Wallet](signer)
  * [VoidSigner](signer)
  * [ExternallyOwnedAccount](signer)
* [Contract Interaction](contract)
  * [Contract](contract/contract)
    * [Creating Instances](contract/contract)
    * [Properties](contract/contract)
    * [Methods](contract/contract)
    * [Events](contract/contract)
    * [Meta-Class](contract/contract)
  * [ContractFactory](contract/contract-factory)
    * [Creating Instances](contract/contract-factory)
    * [Properties](contract/contract-factory)
    * [Methods](contract/contract-factory)
  * [Example: ERC-20 Contract](contract/example)
    * [Connecting to a Contract](contract/example)
    * [Properties](contract/example)
    * [Methods](contract/example)
    * [Events](contract/example)
    * [Meta-Class Methods](contract/example)
    * [Meta-Class Filters](contract/example)
* [Utilities](utils)
  * [Application Binary Interface](utils/abi)
    * [AbiCoder](utils/abi/coder)
      * [Creating Instance](utils/abi/coder)
      * [Coding Methods](utils/abi/coder)
    * [ABI Formats](utils/abi/formats)
      * [Human-Readable ABI](utils/abi/formats)
      * [Solidity JSON ABI](utils/abi/formats)
    * [Fragments](utils/abi/fragments)
      * [Formats](utils/abi/fragments)
      * [Fragment](utils/abi/fragments)
      * [ConstructorFragment](utils/abi/fragments)
      * [EventFragment](utils/abi/fragments)
      * [FunctionFragment](utils/abi/fragments)
      * [ParamType](utils/abi/fragments)
    * [Interface](utils/abi/interface)
      * [Creating Instances](utils/abi/interface)
      * [Properties](utils/abi/interface)
      * [Formatting](utils/abi/interface)
      * [Fragment Access](utils/abi/interface)
      * [Signature and Topic Hashes](utils/abi/interface)
      * [Encoding Data](utils/abi/interface)
      * [Decoding Data](utils/abi/interface)
      * [Parsing](utils/abi/interface)
      * [Types](utils/abi/interface)
      * [Specifying Fragments](utils/abi/interface)
  * [Addresses](utils/address)
    * [Address Formats](utils/address)
    * [Converting and Verifying](utils/address)
    * [Derivation](utils/address)
    * [Contracts Addresses](utils/address)
  * [BigNumber](utils/bignumber)
    * [Types](utils/bignumber)
    * [Creating Instances](utils/bignumber)
    * [Methods](utils/bignumber)
    * [Notes](utils/bignumber)
  * [Byte Manipulation](utils/bytes)
    * [Types](utils/bytes)
    * [Inspection](utils/bytes)
    * [Converting between Arrays and Hexstrings](utils/bytes)
    * [Array Manipulation](utils/bytes)
    * [Hexstring Manipulation](utils/bytes)
    * [Signature Conversion](utils/bytes)
    * [Random Bytes](utils/bytes)
  * [Constants](utils/constants)
    * [Bytes](utils/constants)
    * [Strings](utils/constants)
    * [BigNumber](utils/constants)
  * [Display Logic and Input](utils/display-logic)
    * [Units](utils/display-logic)
    * [Functions](utils/display-logic)
  * [Encoding Utilities](utils/encoding)
    * [Base58](utils/encoding)
    * [Base64](utils/encoding)
    * [Recursive-Length Prefix](utils/encoding)
  * [FixedNumber](utils/fixednumber)
    * [Creating Instances](utils/fixednumber)
    * [Properties](utils/fixednumber)
    * [Methods](utils/fixednumber)
    * [FixedFormat](utils/fixednumber)
  * [Hashing Algorithms](utils/hashing)
    * [Cryptographic Hash Functions](utils/hashing)
    * [HMAC](utils/hashing)
    * [Hashing Helpers](utils/hashing)
    * [Solidity Hashing Algorithms](utils/hashing)
  * [HD Wallet](utils/hdnode)
    * [Types](utils/hdnode)
    * [HDNode](utils/hdnode)
    * [Other Functions](utils/hdnode)
  * [Logging](utils/logger)
    * [Logger](utils/logger)
    * [Errors](utils/logger)
    * [Log Levels](utils/logger)
  * [Property Utilities](utils/properties)
  * [Signing Key](utils/signing-key)
    * [Other Functions](utils/signing-key)
  * [Strings](utils/strings)
    * [Bytes32String](utils/strings)
    * [UTF-8 Strings](utils/strings)
    * [UnicodeNormalizationForm](utils/strings)
    * [Custom UTF-8 Error Handling](utils/strings)
  * [Transactions](utils/transactions)
    * [Types](utils/transactions)
    * [Functions](utils/transactions)
  * [Web Utilities](utils/web)
  * [Wordlists](utils/wordlists)
    * [Wordlist](utils/wordlists)
    * [Languages](utils/wordlists)
* [Other Libraries](other)
  * [Assembly](other/assembly)
    * [Ethers ASM Dialect](other/assembly/dialect)
      * [Opcodes](other/assembly/dialect)
      * [Labels](other/assembly/dialect)
      * [Literals](other/assembly/dialect)
      * [Comments](other/assembly/dialect)
      * [Scopes](other/assembly/dialect)
      * [Data Segment](other/assembly/dialect)
      * [Links](other/assembly/dialect)
      * [Stack Placeholders](other/assembly/dialect)
      * [Evaluation and Excution](other/assembly/dialect)
    * [Utilities](other/assembly/api)
      * [Assembler](other/assembly/api)
      * [Disassembler](other/assembly/api)
      * [Opcode](other/assembly/api)
    * [Abstract Syntax Tree](other/assembly/ast)
      * [Types](other/assembly/ast)
      * [Nodes](other/assembly/ast)
  * [Hardware Wallets](other/hardware)
    * [LedgerSigner](other/hardware)
* [Experimental](experimental)
  * [BrainWallet](experimental)
  * [EIP1193Bridge](experimental)
  * [NonceManager](experimental)

==> v5.0.24.zip: ethers.js/docs/v5/api/README.md <==
-----

Documentation: [html](https://docs.ethers.io/)

-----

Application Programming Interface
=================================

* [Providers](providers)
  * [Provider](providers/provider)
    * [Accounts Methods](providers/provider)
    * [Blocks Methods](providers/provider)
    * [Ethereum Naming Service (ENS) Methods](providers/provider)
    * [Logs Methods](providers/provider)
    * [Network Status Methods](providers/provider)
    * [Transactions Methods](providers/provider)
    * [Event Emitter Methods](providers/provider)
    * [Inspection Methods](providers/provider)
  * [JsonRpcProvider](providers/jsonrpc-provider)
    * [JsonRpcSigner](providers/jsonrpc-provider)
    * [JsonRpcUncheckedSigner](providers/jsonrpc-provider)
    * [Node-Specific Methods](providers/jsonrpc-provider)
  * [API Providers](providers/api-providers)
    * [EtherscanProvider](providers/api-providers)
    * [InfuraProvider](providers/api-providers)
    * [AlchemyProvider](providers/api-providers)
    * [CloudflareProvider](providers/api-providers)
  * [Other Providers](providers/other)
    * [FallbackProvider](providers/other)
    * [IpcProvider](providers/other)
    * [UrlJsonRpcProvider](providers/other)
    * [Web3Provider](providers/other)
    * [WebSocketProvider](providers/other)
  * [Types](providers/types)
    * [BlockTag](providers/types)
    * [Networkish](providers/types)
    * [Network](providers/types)
    * [Block](providers/types)
    * [Events and Logs](providers/types)
    * [Transactions](providers/types)
* [Signers](signer)
  * [Signer](signer)
  * [Wallet](signer)
  * [VoidSigner](signer)
  * [ExternallyOwnedAccount](signer)
* [Contract Interaction](contract)
  * [Contract](contract/contract)
    * [Creating Instances](contract/contract)
    * [Properties](contract/contract)
    * [Methods](contract/contract)
    * [Events](contract/contract)
    * [Meta-Class](contract/contract)
  * [ContractFactory](contract/contract-factory)
    * [Creating Instances](contract/contract-factory)
    * [Properties](contract/contract-factory)
    * [Methods](contract/contract-factory)
  * [Example: ERC-20 Contract](contract/example)
    * [Connecting to a Contract](contract/example)
    * [Properties](contract/example)
    * [Methods](contract/example)
    * [Events](contract/example)
    * [Meta-Class Methods](contract/example)
    * [Meta-Class Filters](contract/example)
* [Utilities](utils)
  * [Application Binary Interface](utils/abi)
    * [AbiCoder](utils/abi/coder)
      * [Creating Instance](utils/abi/coder)
      * [Coding Methods](utils/abi/coder)
    * [ABI Formats](utils/abi/formats)
      * [Human-Readable ABI](utils/abi/formats)
      * [Solidity JSON ABI](utils/abi/formats)
    * [Fragments](utils/abi/fragments)
      * [Formats](utils/abi/fragments)
      * [Fragment](utils/abi/fragments)
      * [ConstructorFragment](utils/abi/fragments)
      * [EventFragment](utils/abi/fragments)
      * [FunctionFragment](utils/abi/fragments)
      * [ParamType](utils/abi/fragments)
    * [Interface](utils/abi/interface)
      * [Creating Instances](utils/abi/interface)
      * [Properties](utils/abi/interface)
      * [Formatting](utils/abi/interface)
      * [Fragment Access](utils/abi/interface)
      * [Signature and Topic Hashes](utils/abi/interface)
      * [Encoding Data](utils/abi/interface)
      * [Decoding Data](utils/abi/interface)
      * [Parsing](utils/abi/interface)
      * [Types](utils/abi/interface)
      * [Specifying Fragments](utils/abi/interface)
  * [Addresses](utils/address)
    * [Address Formats](utils/address)
    * [Converting and Verifying](utils/address)
    * [Derivation](utils/address)
    * [Contracts Addresses](utils/address)
  * [BigNumber](utils/bignumber)
    * [Types](utils/bignumber)
    * [Creating Instances](utils/bignumber)
    * [Methods](utils/bignumber)
    * [Notes](utils/bignumber)
  * [Byte Manipulation](utils/bytes)
    * [Types](utils/bytes)
    * [Inspection](utils/bytes)
    * [Converting between Arrays and Hexstrings](utils/bytes)
    * [Array Manipulation](utils/bytes)
    * [Hexstring Manipulation](utils/bytes)
    * [Signature Conversion](utils/bytes)
    * [Random Bytes](utils/bytes)
  * [Constants](utils/constants)
    * [Bytes](utils/constants)
    * [Strings](utils/constants)
    * [BigNumber](utils/constants)
  * [Display Logic and Input](utils/display-logic)
    * [Units](utils/display-logic)
    * [Functions](utils/display-logic)
  * [Encoding Utilities](utils/encoding)
    * [Base58](utils/encoding)
    * [Base64](utils/encoding)
    * [Recursive-Length Prefix](utils/encoding)
  * [FixedNumber](utils/fixednumber)
    * [Creating Instances](utils/fixednumber)
    * [Properties](utils/fixednumber)
    * [Methods](utils/fixednumber)
    * [FixedFormat](utils/fixednumber)
  * [Hashing Algorithms](utils/hashing)
    * [Cryptographic Hash Functions](utils/hashing)
    * [HMAC](utils/hashing)
    * [Hashing Helpers](utils/hashing)
    * [Solidity Hashing Algorithms](utils/hashing)
  * [HD Wallet](utils/hdnode)
    * [Types](utils/hdnode)
    * [HDNode](utils/hdnode)
    * [Other Functions](utils/hdnode)
  * [Logging](utils/logger)
    * [Logger](utils/logger)
    * [Errors](utils/logger)
    * [Log Levels](utils/logger)
  * [Property Utilities](utils/properties)
  * [Signing Key](utils/signing-key)
    * [Other Functions](utils/signing-key)
  * [Strings](utils/strings)
    * [Bytes32String](utils/strings)
    * [UTF-8 Strings](utils/strings)
    * [UnicodeNormalizationForm](utils/strings)
    * [Custom UTF-8 Error Handling](utils/strings)
  * [Transactions](utils/transactions)
    * [Types](utils/transactions)
    * [Functions](utils/transactions)
  * [Web Utilities](utils/web)
  * [Wordlists](utils/wordlists)
    * [Wordlist](utils/wordlists)
    * [Languages](utils/wordlists)
* [Other Libraries](other)
  * [Assembly](other/assembly)
    * [Ethers ASM Dialect](other/assembly/dialect)
      * [Opcodes](other/assembly/dialect)
      * [Labels](other/assembly/dialect)
      * [Literals](other/assembly/dialect)
      * [Comments](other/assembly/dialect)
      * [Scopes](other/assembly/dialect)
      * [Data Segment](other/assembly/dialect)
      * [Links](other/assembly/dialect)
      * [Stack Placeholders](other/assembly/dialect)
      * [Evaluation and Execution](other/assembly/dialect)
    * [Utilities](other/assembly/api)
      * [Assembler](other/assembly/api)
      * [Disassembler](other/assembly/api)
      * [Opcode](other/assembly/api)
    * [Abstract Syntax Tree](other/assembly/ast)
      * [Types](other/assembly/ast)
      * [Nodes](other/assembly/ast)
  * [Hardware Wallets](other/hardware)
    * [LedgerSigner](other/hardware)
* [Experimental](experimental)
  * [BrainWallet](experimental)
  * [EIP1193Bridge](experimental)
  * [NonceManager](experimental)
